@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: bufferstore.cc,v 1.11 2002/07/14 06:35:33 felfert Exp $
+ * $Id: bufferstore.cc,v 1.12 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -25,16 +25,17 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <stream.h>
-// Should be iostream.h, but won't build on Sun WorkShop C++ 5.0
-#include <iomanip>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
-#include <assert.h>
 
 #include "bufferstore.h"
 
+// Should be iostream.h, but won't build on Sun WorkShop C++ 5.0
+#include <iomanip>
+#include <string>
+
+#include <stdlib.h>
+#include <ctype.h>
+#include <assert.h>
+
 using namespace std;
 
 bufferStore::bufferStore()
